contracts\_lib\_py.conditions.compute\_execution module
=======================================================

.. automodule:: contracts_lib_py.conditions.compute_execution
   :members:
   :undoc-members:
   :show-inheritance:
